@@ -18,7 +18,7 @@ from bip_utils.addr import (
     OkexAddrDecoder, OkexAddrEncoder, OkexAddr,
     OneAddrDecoder, OneAddrEncoder, OneAddr,
     BchP2PKHAddrDecoder, BchP2PKHAddrEncoder, BchP2PKHAddr,
-    P2PKHAddrDecoder, P2PKHAddrEncoder, P2PKHAddr,
+    P2PKHPubKeyModes, P2PKHAddrDecoder, P2PKHAddrEncoder, P2PKHAddr,
     BchP2SHAddrDecoder, BchP2SHAddrEncoder, BchP2SHAddr,
     P2SHAddrDecoder, P2SHAddrEncoder, P2SHAddr,
     P2WPKHAddrDecoder, P2WPKHAddrEncoder, P2WPKHAddr,
@@ -67,6 +67,7 @@ from bip_utils.bip.bip39 import (
 from bip_utils.bip.bip32 import (
     Bip32KeyError, Bip32PathError,
     Bip32ChainCode, Bip32Depth, Bip32FingerPrint, Bip32KeyIndex, Bip32KeyNetVersions, Bip32KeyData,
+    Bip32PublicKeySerializer, Bip32PrivateKeySerializer, Bip32DeserializedKey, Bip32KeyDeserializer,
     Bip32Path, Bip32PathParser,
     Bip32PublicKey, Bip32PrivateKey,
     Bip32Utils,
@@ -89,6 +90,7 @@ from bip_utils.bip.conf.bip86 import Bip86Coins, Bip86Conf, Bip86ConfGetter
 from bip_utils.coin_conf import CoinsConf
 # ECC
 from bip_utils.ecc import (
+    IPublicKey, IPrivateKey,
     EllipticCurveGetter, EllipticCurveTypes,
     Ed25519, Ed25519Point, Ed25519PublicKey, Ed25519PrivateKey,
     Ed25519Kholaw, Ed25519KholawPoint, Ed25519KholawPublicKey, Ed25519KholawPrivateKey,
@@ -98,6 +100,23 @@ from bip_utils.ecc import (
     Secp256k1, Secp256k1Point, Secp256k1PublicKey, Secp256k1PrivateKey,
     Sr25519, Sr25519Point, Sr25519PublicKey, Sr25519PrivateKey
 )
+# Electrum mnemonic
+from bip_utils.electrum.mnemonic_v1 import (
+    ElectrumV1EntropyBitLen, ElectrumV1Languages, ElectrumV1WordsNum,
+    ElectrumV1EntropyGenerator,
+    ElectrumV1Mnemonic,
+    ElectrumV1MnemonicDecoder, ElectrumV1MnemonicEncoder,
+    ElectrumV1MnemonicGenerator, ElectrumV1MnemonicValidator, ElectrumV1SeedGenerator
+)
+from bip_utils.electrum.mnemonic_v2 import (
+    ElectrumV2EntropyBitLen, ElectrumV2Languages, ElectrumV2WordsNum,
+    ElectrumV2EntropyGenerator,
+    ElectrumV2MnemonicTypes, ElectrumV2Mnemonic,
+    ElectrumV2MnemonicDecoder, ElectrumV2MnemonicEncoder,
+    ElectrumV2MnemonicGenerator, ElectrumV2MnemonicValidator, ElectrumV2SeedGenerator
+)
+# Electrum wallet
+from bip_utils.electrum import ElectrumV1, ElectrumV2Standard, ElectrumV2Segwit
 # Monero
 from bip_utils.monero import (
     MoneroKeyError, MoneroPublicKey, MoneroPrivateKey, MoneroSubaddress, Monero
@@ -113,6 +132,10 @@ from bip_utils.monero.mnemonic import (
 )
 # Monero configuration
 from bip_utils.monero.conf import MoneroCoins, MoneroConf
+# SLIP32
+from bip_utils.slip.slip32 import (
+    Slip32PublicKeySerializer, Slip32PrivateKeySerializer, Slip32DeserializedKey, Slip32KeyDeserializer
+)
 # Solana
 from bip_utils.solana import SplToken
 # SS58
