@@ -32,10 +32,6 @@ class Bech32BaseConst:
 
     # Character set
     CHARSET: str = "qpzry9x8gf2tvdw0s3jn54khce6mua7l"
-    # Maximum string length in bytes
-    MAX_STR_BYTE_LEN: int = 90
-    # Data part minimum length in bytes
-    MIN_DATA_PART_BYTE_LEN: int = 7
 
 
 class Bech32BaseUtils:
@@ -204,8 +200,8 @@ class Bech32DecoderBase(ABC):
         """
 
         # Check string length and case
-        if len(bech_str) > Bech32BaseConst.MAX_STR_BYTE_LEN or AlgoUtils.IsStringMixed(bech_str):
-            raise ValueError(f"Invalid bech32 format (length not valid: {len(bech_str)})")
+        if AlgoUtils.IsStringMixed(bech_str):
+            raise ValueError("Invalid bech32 format (string is mixed case)")
 
         # Lower string
         bech_str = bech_str.lower()
@@ -222,7 +218,7 @@ class Bech32DecoderBase(ABC):
 
         # Get data and check it
         data_part = bech_str[sep_pos + 1:]
-        if (len(data_part) < Bech32BaseConst.MIN_DATA_PART_BYTE_LEN
+        if (len(data_part) < (checksum_len + 1)
                 or not all(x in Bech32BaseConst.CHARSET for x in data_part)):
             raise ValueError("Invalid bech32 format (data part not valid)")
 
